<!-- warning: Please don't edit this file. It was automatically generated. -->

# winrt-Windows.Media.Capture

Windows Runtime (WinRT) APIs for for the `Windows.Media.Capture` namespace.

This package provides the `winrt.windows.media.capture` module.
